import sys, numpy as np, scipy.constants, matplotlib.pyplot as plt, math as m
sys.path.append("../lib")
from density import *
from emf import emf_x
from matplotlib import cm
import phaseDiagramme as pd
f, ax = plt.subplots(1,1)
f.set_size_inches(5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)

ax.set_ylabel(r'$T$ in $^\circ$C')
ax.set_xlabel(r'$x$')

ax.set_yticks((415,450,500,550,600,650))

# generate data mesh
T = np.linspace(415, 600, 500, endpoint=True) #°C
x = np.linspace(0, 1, 500, endpoint=True)
x, T = np.meshgrid(x, T)

# plot fitted data
E = emf_x(x, T)

#Test plot liquidus lines
Tliq, xliq1, xliq2 = pd.Tliq()
ax.plot(xliq2(np.linspace(415, 600, 100, endpoint=True)),np.linspace(415, 600, 100, endpoint=True),linewidth=0.5, linestyle='dashed',color='black')
ax.text(0.41,440,"liquidus",fontsize=7)
#ax.plot(np.linspace(0.38, 0.49, 50, endpoint=True),Tliq(np.linspace(0.38, 0.49, 50, endpoint=True)),linewidth=0.25, color='red')

T_T = np.linspace(400, 415, 11, endpoint=True) #°C
x_T = np.linspace(0.35, 0.4, 11, endpoint=True)
x_T, T_T = np.meshgrid(x_T, T_T)
Test= emf_x(x_T, T_T)

#cmap = plt.get_cmap('YlOrBr')
cmap = plt.get_cmap('afmhot_r')
levels = np.linspace(0, 1.1, 23, endpoint=True)
im1 = ax.contourf(x, T, E, levels=levels, cmap=cmap)
levels2 = np.array([1.1, 1.05, 1, 0.95, 0.9, 0.85, 0.8, 0.75, 0.725, 0.7, 0.675, 0.65,0.625])
im2 = ax.contour(im1, levels=levels2, colors='w', linewidths=0.1)
manual_locations = [(0.01,490), (0.07,500), (0.2,505),(0.3,510),(0.55,475),(0.6,525),(0.6,550)]
labels=ax.clabel(im2, inline=True, fmt='%1.3f', fontsize=9, manual=manual_locations)
labels[3].set_rotation(90)
labels[0].set_fontsize(7)
cb1 = f.colorbar(im1, ax=ax, ticks=[0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1,1.1])
cb1.set_label(r'$E_\mathrm{eq}$ in V', labelpad=10.)

f.subplots_adjust(left=0.12,bottom=0.15,right=0.99,top=0.98,wspace=0.05,hspace=0.08)
f.savefig("f.pdf")
