import numpy as np, matplotlib.pyplot as plt
import scipy.special


def BesselCoeffDerivative(m,n):
    roots=scipy.special.jnp_zeros(m,400)    
    return roots[n-1]  

EpsValues = np.zeros(401)

for n in range(400):
    EpsValues[n+1] = BesselCoeffDerivative(0,n+1)   

# R1: large, lower radius; H: electrolyte height
def deltaPhi(I, sigma, R1, R2, H):
    return (I/(sigma*np.pi)) * ((H-0.178*R2)/(R1*R1) + 1./R2 - 1./np.sqrt(R1*R2))


def deltaPhiExact(I,H,sigma,R1,R2): 
    phi = (I*H)/(sigma*np.pi*R1*R1)
    for n in range(1,400): 
        eps = EpsValues[n]
        phi += (2*I)/(sigma*np.pi*R2)*(scipy.special.jv(1,eps*(R2/R1))/(eps*eps*scipy.special.jv(0,eps)*scipy.special.jv(0,eps)))*np.tanh(0.5*eps*H/R1) 
    return phi

def deltaPhiExact2(I,H,sigma,R1,R2): 
    phi = (I*H)/(sigma*np.pi*R1*R1)
    for n in range(1,400): 
        eps = EpsValues[n]
        phi += ((np.pi*scipy.special.struve(0, eps*(R2/R1))*scipy.special.jv(1,eps*(R2/R1)) + (2.- np.pi*scipy.special.struve(1, eps*(R2/R1)))*scipy.special.jv(0,eps*(R2/R1)))*I)/(sigma*np.pi*R2)*(scipy.special.jv(1,eps*(R2/R1))/(eps*eps*scipy.special.jv(0,eps)*scipy.special.jv(0,eps)))*np.tanh(0.5*eps*H/R1) 
    return phi


f, ax = plt.subplots()
f.set_size_inches(5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)

I = 1
sigma = 100
R1 = 0.05
R2 = np.linspace(0.015, 0.05, 100, endpoint=True)
H = np.linspace(0.0025, 0.021, 100, endpoint=True)
R2, H = np.meshgrid(R2, H)

levels = np.linspace(0, 0.11, 100, endpoint=True)
cmap='inferno_r'#'cividis'#'inferno'#'afmhot_r'
#im1 = ax.contourf(R2/R1, 1e3*H, deltaPhi(I,sigma,R1,R2,H), levels=levels, cmap=cmap, extend="both")
im1 = ax.contourf(R2/R1, 1e3*H, deltaPhiExact2(I,H,sigma,R1,R2), levels=levels, cmap=cmap, extend="both")

levels2 = np.linspace(0, 0.11, 10, endpoint=True)
im2 = ax.contour(im1, levels=levels2, colors='k', linewidths=0.1)
cbar = f.colorbar(im1, ax=ax, label=r'$\eta_\Omega$ in V', ticks=[0,0.02,0.04,0.06,0.08,0.1])


# save image
ax.set(xlabel=r"$R_2/R_1$", ylabel=r"$H$ in mm")

f.subplots_adjust(left=0.13,bottom=0.15,right=0.98,top=0.98,wspace=0.15,hspace=0.25)
f.savefig("f3.pdf")
