import numpy as np, matplotlib.pyplot as plt, matplotlib.tri as tri
import scipy.special


def BesselCoeffDerivative(m,n):
    roots=scipy.special.jnp_zeros(m,400)    
    return roots[n-1] 

EpsValues = np.zeros(401)

for n in range(400):
    EpsValues[n+1] = BesselCoeffDerivative(0,n+1)   

# R1: large, lower radius; H: electrolyte height
def deltaPhi(I, sigma, R1, R2, H):
    return (I/(sigma*np.pi)) * ((H-0.178*R2)/(R1*R1) + 1./R2 - 1./np.sqrt(R1*R2))


def deltaPhiExact(I,H,sigma,R1,R2): 
    phi = (I*H)/(sigma*np.pi*R1*R1)
    for n in range(1,400): 
        eps = EpsValues[n]
        phi += (2*I)/(sigma*np.pi*R2)*(scipy.special.jv(1,eps*(R2/R1))/(eps*eps*scipy.special.jv(0,eps)*scipy.special.jv(0,eps)))*np.tanh(0.5*eps*H/R1) 
    return phi

def deltaPhiExact2(I,H,sigma,R1,R2): 
    phi = (I*H)/(sigma*np.pi*R1*R1)
    for n in range(1,400): 
        eps = EpsValues[n]
        phi += ((np.pi*scipy.special.struve(0, eps*(R2/R1))*scipy.special.jv(1,eps*(R2/R1)) + (2.- np.pi*scipy.special.struve(1, eps*(R2/R1)))*scipy.special.jv(0,eps*(R2/R1)))*I)/(sigma*np.pi*R2)*(scipy.special.jv(1,eps*(R2/R1))/(eps*eps*scipy.special.jv(0,eps)*scipy.special.jv(0,eps)))*np.tanh(0.5*eps*H/R1) 
    return phi

f, ax = plt.subplots()
f.set_size_inches(5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)

# read OpenFOAM data from file
data = np.genfromtxt('data', skip_header=1)
R1 = data[:,0]	# lower radius (large)
R2 = data[:,1]	# upper radius
H = data[:,2]
loss = data[:,3]

# add ohmic loss for cases where upper and lower radius are equal
h = np.arange(0.002, 0.022, 0.002)
r = np.full((h.size), 0.05) # radius
# formula: loss = I*h / (A*sigma)
# I = sigma = 1; A = pi*r*r with r=0.05 m
loss2 = h/(np.pi*0.05*0.05)
R1 = np.append(R1, r)
R2 = np.append(R2, r)
H = np.append(H, h)
loss = np.append(loss, loss2)

# compute error between simulation and Gerrit's formula
I = 1
sigma = 1
#error = 100*np.abs((loss - deltaPhi(I,sigma,R1,R2,H)) / loss)
error = 100*np.abs((loss - deltaPhiExact2(I,H,sigma,R1,R2)) / loss)

# plot the error
levels = [3,10,20,30]
cs1 = ax.tricontour(R2/R1, 1e3*H, error, levels, linewidths=0.5, colors='k')
cntr = ax.tricontourf(R2/R1, 1e3*H, error, levels, cmap="Oranges", extend="both")
cntr.set_clim(vmin=0, vmax=50) # range of colourbar

f.colorbar(cntr, ax=ax, label=r'error in %')
manual_locations = [(0.55,18), (0.63,17), (0.55,15), (0.62,13), (0.5,11), (0.55,8), (0.5,5), (0.4,4)]
ax.clabel(cs1, inline=True, fmt='%1.0f', fontsize=10, manual=manual_locations)

# save image
ax.set(xlabel=r"$R_2 / R_1$", ylabel=r"$H$ in mm")
ax.set_xlim(0.3,1)
ax.set_ylim(2.5,20)

f.subplots_adjust(left=0.13,bottom=0.15,right=.99,top=0.97,wspace=0.15,hspace=0.25)
f.savefig("f4.pdf")
