
import numpy as np, matplotlib.pyplot as plt, matplotlib.tri as tri, sys
sys.path.append("../lib")

f, ax = plt.subplots()
f.set_size_inches(5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)

# read OpenFOAM data from file
data = np.genfromtxt('dataR', skip_header=1)
R1 = data[:,0]	# lower radius (large)
R2 = data[:,1]	# upper radius
H = data[:,2]
loss = data[:,3]

# add ohmic loss for cases where upper and lower radius are equal
h = np.arange(0.002, 0.022, 0.002)
r = np.full((h.size), 0.05) # radius
# formula: loss = I*h / (A*sigma)
# I = sigma = 1; A = r*r with r=0.05 m
loss2 = h/(0.05*0.05)
R1 = np.append(R1, r)
R2 = np.append(R2, r)
H = np.append(H, h)
loss = np.append(loss, loss2)

# compute error between simulation and fitted formula
I = 4
sigma = 1
from ohm import etaSquare
ohm = etaSquare(I, sigma, 2*R1, 2*R2, H)
error = 100*np.abs((loss - ohm) / loss)

# plot the error
levels = [0,0.4,0.8,1.2,1.6]
cs1 = ax.tricontour(R2/R1, 1e3*H, error, levels, linewidths=0.5, colors='k')
cntr = ax.tricontourf(R2/R1, 1e3*H, error, levels, cmap="Oranges", extend="both")
#cntr.set_clim(vmin=0, vmax=5) # range of colourbar
f.colorbar(cntr, ax=ax, label=r'error in %')
#manual_locations = [(0.35,16), (0.4,13), (0.5,11), (0.55,8), (0.6,5.5), (0.5,5), (0.4,4)]
#ax.clabel(cs1, inline=True, fmt='%1.0f', fontsize=10, manual=manual_locations)

# save image
ax.set(xlabel=r"$R_2 / R_1$", ylabel=r"$H$ in mm")
ax.set_xlim(0.3,1)
ax.set_ylim(2.5,20)

f.subplots_adjust(left=0.13,bottom=0.15,right=1,top=0.97,wspace=0.15,hspace=0.25)
f.savefig("f6.pdf")
