
import sys, numpy as np, scipy.constants, matplotlib.pyplot as plt
sys.path.append("../lib")
from LiBi import *
from density import rhoLiBi_x
#import density



################################################################################
# define materials and dimensions
################################################################################

# define dimensions
d1 = 0.15		# diameter bottom (Ning paper)
A = np.pi*d1*d1/4.0     # surface area (bottom)
hE1 = 0.01              # electrolyte layer height, start of discharge


# define initial condition
mBi = 455.28*1e-3	
nBi = mBi / MBi()
T = 550


################################################################################
# plot measurement
################################################################################

helmholtzBlau          = (       0.,  88./255., 156./255.)
rossendorfOrange       = (207./255., 104./255., 0.)
helmholtzDunkelBlau    = (       0.,  62./255., 110./255.)
grau1                  = ( 81./255.,  81./255.,  81./255. )
grau2                  = (156./255., 156./255., 156./255.)
grau3                  = (185./255., 185./255., 185./255.)
gesundheit             = (212./255.,  45./255.,  18./255.)
strukturDerMaterie     = (207./255., 104./255.,   0.)
energie                = (230./255., 175./255.,  17./255.)
erdeUndUmwelt          = ( 20./255.,  77./255.,  40./255.)
schluesseltechnologien = (169./255., 181./255.,   9./255.)
verkehrUndWeltraum     = (       0., 162./255., 224./255.)

f, ax = plt.subplots()
f.set_size_inches(6,4)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)

x = np.linspace(0, 0.75, 100, endpoint=True)      # charge, which can be transferred: 3*nBi*F
h = (x*nBi*MLi()/(1.-x) + mBi)/(A*rhoLiBi_x(x, T))

plt.plot(x, 1e3*h, linewidth=2, label='experiment', color='k')


plt.ylim(2.5,6.5)
plt.xlim(0,0.75)

ax.set(xlabel=r"$x_\mathrm{Li}$", ylabel=r"$H$ in mm")
#plt.legend(loc='upper right')

f.subplots_adjust(left=0.1,bottom=0.11,right=0.98,top=0.98,wspace=0.15,hspace=0.25)
f.savefig("f.pdf")
