
import sys, numpy as np, matplotlib.pyplot as plt
sys.path.append("../lib")
from density import *
from LiBi import *

helmholtzBlau          = (       0.,  88./255., 156./255.)
rossendorfOrange       = (207./255., 104./255., 0.)
helmholtzDunkelBlau    = (       0.,  62./255., 110./255.)
grau1                  = ( 81./255.,  81./255.,  81./255. )
grau2                  = (156./255., 156./255., 156./255.)
grau3                  = (185./255., 185./255., 185./255.)

f, ax = plt.subplots()
f.set_size_inches(5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)


# read density data from file
rhoWax = np.genfromtxt('rhoWax',skip_header=2)
rhoStein1 = np.genfromtxt('rhoStein1',skip_header=2)
rhoStein2 = np.genfromtxt('rhoStein2',skip_header=2)
#rhoStein3 = np.genfromtxt('rhoStein3',skip_header=2)

ax.set_xlim(0,1)
ax.set_ylim(0,10)

# plot Vegard's law
from density import *
x = np.linspace(0, 1, 100)

density800 = Vegard_x(x,MLi(),MBi(),rhoLi(800),rhoBi(800))
plt.plot(x, 1e-3*density800, label="Vegard's law (800°C)", color=grau3)

plt.plot(x, 1e-3*rhoLiBi_x(x, 800), '-', label='Fit (800°C)', color=helmholtzBlau)
plt.plot(x, 1e-3*rhoLiBi_x(x, 1100.), '--', label='Fit (1100°C)', color=helmholtzBlau)

# and plot it
plt.plot(1.-rhoWax[:,0],1e-3*rhoWax[:,1],'o',linewidth=1,label='Wax (2011), 800°C',color='k')
plt.plot(1.-rhoStein1[:,0],1e-3*rhoStein1[:,1],'^',linewidth=1,label='Steinleitner (1975), 900°C', color='k')
plt.plot(1.-rhoStein2[:,0],1e-3*rhoStein2[:,1],'D',linewidth=1,label='Steinleitner (1975), 1100°C', color='k')
#plt.plot(1.-rhoStein3[0],rhoStein3[1],'x',linewidth=1,label='Steinleitner (1975), 1150°C (not used)')

ax.set(xlabel=r"$x$", ylabel=r"$\rho$ in g/cm$^3$")
plt.legend(fontsize=9.)

f.subplots_adjust(left=0.11,bottom=0.14,right=0.98,top=0.98,wspace=0.15,hspace=0.25)
f.savefig("f1.pdf")
