
import sys, numpy as np, matplotlib.pyplot as plt
sys.path.append("../lib")
from density import *

helmholtzBlau          = (       0.,  88./255., 156./255.)
rossendorfOrange       = (207./255., 104./255., 0.)
helmholtzDunkelBlau    = (       0.,  62./255., 110./255.)
grau1                  = ( 81./255.,  81./255.,  81./255. )
grau2                  = (156./255., 156./255., 156./255.)
grau3                  = (185./255., 185./255., 185./255.)

# plot
f, ax = plt.subplots()
f.set_size_inches(5,3)

ax.xaxis.label.set_size(12)
ax.yaxis.label.set_size(12)
ax.tick_params(axis='x', labelsize=10)
ax.tick_params(axis='y', labelsize=10)

# plot measured values by Newhouse; they depend already on "c"
D = np.genfromtxt('Dnewhouse', skip_header=1)
correct=1000 # comes in mol/cm3 -> * 1e6 -> divide by 1e3 to get kmol/m3
# factor 1000

# plot fit of Newhouse (p. 174)
c = np.linspace(0,0.06,100)
Dc = 1e5*np.exp((-4.081*c-0.01315) / ( c*c + 0.3742*c + 0.001572))
plt.plot(correct*c,Dc,label='Newhouse (fit)', color=helmholtzBlau)

plt.plot(correct*D[:,0],D[:,1],'o',linewidth=1,label='Newhouse (measured)', color='k')

Dweppner1 = np.genfromtxt('Dweppner1',skip_header=1)
Dweppner2 = np.genfromtxt('Dweppner2',skip_header=1)

plt.plot(1e-3*xToC(np.array([0.75,0.75]), 400.),1e5 * 10**Dweppner1[:,1],'^',linewidth=1,label='Weppner (400°C, pure Li$_3$Bi)', color='k')
plt.plot(1e-3*xToC(np.array([0.74]), 400.),1e5 * 10**Dweppner2[1],'D',linewidth=1,label='Weppner (400°C, Li$_{2.85}$Bi)', color='k')

# plot values of other sources

D = np.genfromtxt('Dtemnogorova1',skip_header=2)
x=np.array([0,1.])
plt.plot(1e-3*xToC(x, 500.),[1e9*D[0],1e9*D[0]], '-', label='Temnogorova (500°C, c unknown)', color=grau2)

D = np.genfromtxt('Dtemnogorova2',skip_header=2)
plt.plot(1e-3*xToC(x, 550.),1e9*D[:,0], '--', label='Temnogorova (550°C, c unknown)', color=grau2)

D = np.genfromtxt('Norman',skip_header=2)
plt.plot(1e-3*xToC(x, 450.),[1e9*D[0],1e9*D[0]], ':', label='van Norman (450°C, c unknown)', color=grau2)

ax.set(xlabel=r"c in kmol/m$^3$", ylabel=r"D in $10^9$m$^2$/s")
plt.legend(fontsize=9.)

plt.xlim(0,60)
#plt.ylim(0,14)

f.subplots_adjust(left=0.11,bottom=0.15,right=0.98,top=0.98,wspace=0.15,hspace=0.25)
f.savefig("f.pdf")
