import numpy as np

def MLi():
    """ Molar mass of Li """
    return 6.941e-3

def MBi():
    """ Molar mass of Bi """
    return 208.9804e-3

def D_c(cReal):
    """ Return diffusivity as function of molar concentration """
    # convert from mol/m3 to mol/cm3
    c = cReal * 1e-6 
    return 1e-4*np.exp( (-4.081*c - 0.01315) / (c*c + 0.3742*c + 0.001572) )

def sigmaLiClFI(T):
    """ Return conductivity of eut. LiCl-LiF-LiI with T in °C """
    T = T+273.15
    return 889.5*np.exp(-872.6 / T)

def sigmaLiClF75(T):
    """ Return conductivity of LiCl-LiF
    - T in °C
    - composition: 75mol%LiCl
    Data source: Janz et al. (1979): Molten Salts: Volume 4, p.141
    """
    TK = T+273.15
    return 100* (-4.53422 + 1.39024e-2*TK - 4.16275e-6*TK*TK)
