""" Phase diagramme Li-Bi from Sangster and Pelton (1991) """

import numpy as np
from scipy.interpolate import UnivariateSpline, InterpolatedUnivariateSpline

def Tliq():
    """ Return liquidus temperature and corresponding molar fraction """
    # values from Sangster and Pelton  (1991): The Bi-Li (Bismuth-Lithium) System
    liquidus = np.array([
        [-0.1, 544.0], # Dummy value for x=0
        [0.0, 544.0], # Exact #1
        [2.5, 539], # Dummy for spline
        [5.8423915, 532.9571],
        [10.0, 524.3147408], # Dummy for spline
        [14.0, 516.0],  # Exact #3
        [20.788044, 577.65234],
        [26.222826, 622.34766],
        [31.52174, 657.5621],
        [35.326088, 673.0],
        [37.0, 688.0],  # Exact #8
        [41.711956, 757.7878],
        [47.010868, 832.2799],
        [52.038044, 908.1264],
        [58.016304, 1006.99774],
        [61.005436, 1059.8195],
        [66.304344, 1191.1964],
        [71.603264, 1340.1805],
        [75.0, 1418.0],  # Exact #16
        [79.61957, 1313.0925],
        [84.23913, 1199.3228],
        [87.63587, 1096.3883],
        [90.48913, 1001.58014],
        [92.934784, 904.06323],
        [94.70109, 798.41986],
        [96.059784, 694.1309],
        [97.28261, 576.298],
        [99.0, 448.0],  # Exact
        [100, 453.7],  # Exact
        [101, 453.7]])  # Dummy value for x=100

    xSangster = liquidus[:,0]*0.01          # convert from %
    TSangster = liquidus[:,1] - 273.15      # to °C

    # Generate spline functions for liquidus line x_Li=0...0.75
    #TliqSpline=UnivariateSpline(xSangster[1:19],TSangster[1:19]) # T(x)
    #xliqSpline1=UnivariateSpline(-TSangster[1:6], xSangster[1:6]) # x(T), left falling arm
    #xliqSpline2=UnivariateSpline(TSangster[5:19], xSangster[5:19]) # x(T), right rising arm
    
    # InterpolatedUnivariateSpline gives better reversibility of T=f(x) and x=f(T)
    TliqSpline=InterpolatedUnivariateSpline(xSangster[1:18],TSangster[1:18]) # T(x)
    xliqSpline1=InterpolatedUnivariateSpline(-TSangster[1:6], xSangster[1:6]) # x(T), left falling arm
    xliqSpline2=InterpolatedUnivariateSpline(TSangster[5:18], xSangster[5:18]) # x(T), right rising arm
    
    return TliqSpline, xliqSpline1, xliqSpline2
